GOOF----LE-8-2.0E      ]  4 h      ] g  gnc:module-load	f  gnucash/html	g  guile	 	g  process-use-modules	 	 	g  gnucash		g  printf	
	 	
 	g  make-record-type	
f  <html-document>	g  style-sheet	g  style-stack	g  style	g  
style-text	g  title	g  headline	g  objects	 	g  <html-document>	g  record-predicate	g  gnc:html-document?	g  record-constructor	g  gnc:make-html-document-internal	g  gnc:make-html-style-table	f   	g  gnc:make-html-document	g  record-modifier	g  gnc:html-document-set-title!	 g  record-accessor	!g  gnc:html-document-title	"g  gnc:html-document-set-headline!	#g  gnc:html-document-headline	$g  "gnc:html-document-set-style-sheet!	%g  gnc:html-document-style-sheet	&g  "gnc:html-document-set-style-stack!	'g  gnc:html-document-style-stack	(g  !gnc:html-document-set-style-text!	)g  gnc:html-document-style-text	*g  %gnc:html-document-set-style-internal!	+g  gnc:html-document-style	,g  gnc:html-document-set-objects!	-g  gnc:html-document-objects	.g  gnc:make-html-markup-style-info	/g  length	0g  
procedure?	1g  gnc:make-html-data-style-info	2g  gnc:html-style-table-set!	3g  gnc:html-document-set-style!	4g  for-each	5g  string?	6g  with-output-to-string	7g  display	8g  gnc:html-document-tree-collapse	9g  gnc:html-style-sheet-render	:g  gnc-html-engine-supports-css	;g  gnc:html-style-table-compile	<g  gnc:html-document-push-style	=g  string-null?	>g  gnc:report-render-starting	?f  g<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN" 
"http://www.w3.org/TR/html4/loose.dtd">	@f  <head>
	Af  F<meta http-equiv="content-type" content="text/html; charset=utf-8" />
	Bf  </style>	Cf  <style type="text/css">
	Df  </title>	Ef  <title>
	Ff  </head>
	Gg  gnc:html-markup/open-tag-only	Hf  body	Ig  gnc:html-object-render	Jg  gnc:report-percent-done	Kf  </body>
	Lf  </html>
	Mg  gnc:report-finished	Ng  gnc:html-document-pop-style	Og  gnc:html-style-table-uncompile	Pg  string-concatenate	Qg  gnc:html-document-render	Rg  append	Sg  gnc:make-html-object	Tg  gnc:html-document-add-object!	Ug  !gnc:html-document-append-objects!	Vg  gnc:html-style-table-fetch	Wg  $gnc:html-document-fetch-markup-style	Xg  sprintf	Yf  %a %a	Zg  "gnc:html-document-fetch-data-style	[g  gnc:html-markup-style-info-tag	\g  %gnc:html-markup-style-info-attributes	]g  $gnc:html-markup-style-info-font-face	^g  $gnc:html-markup-style-info-font-size	_g  %gnc:html-markup-style-info-font-color	`g  string=?	af  
<	bg  	hash-fold	cf   	df  ="	ef  "	fg  gnc:warn	gf  non-string attribute	hf   /	if  >	jf  <	kf  <font 	lf  face="	mf  " 	nf  size="	of  color="	pg  gnc:html-document-markup-start	qg  +gnc:html-markup-style-info-closing-font-tag	rf  </font>
	sf  </	tf  >
	ug  reverse	vg  gnc:html-document-markup-end	wg  number?	xf  <number>	yf  <string>	zg  boolean?	{f  	<boolean>	|g  record?	}g  record-type-name	~g  record-type-descriptor	f  	<generic> g  !gnc:html-data-style-info-renderer g  gnc:html-data-style-info-data g  gnc:html-document-render-data f  
<html-object> g  renderer g  data   g  
<html-object> g  gnc:html-object? g  gnc:make-html-object-internal g  gnc:html-text? g  gnc:html-text-render g  gnc:html-table? g  gnc:html-table-render g  gnc:html-table-cell? g  gnc:html-table-cell-render g  gnc:html-barchart? g  gnc:html-barchart-render g  gnc:html-piechart? g  gnc:html-piechart-render g  gnc:html-scatter? g  gnc:html-scatter-render g  gnc:html-linechart? g  gnc:html-linechart-render f  &nbsp;&nbsp;&nbsp; g  gnc:html-object-renderer g  gnc:html-object-set-renderer! g  gnc:html-object-data g  gnc:html-object-set-data!C 5  h0  5  ] 4i
>  "  G  4 >  "  G  4i
5R4ii5R4ii5R        h      ] 45 6             g  filenamef  html-document.scm
	)
		,			-			/			1			*	 		
  g  nameg  gnc:make-html-document CR4ii5R4 ii5!R4ii5"R4 ii5#R4ii5$R4ii5$R4 ii5%R4ii5&R4 ii5'R4ii5(R4 ii5)R4ii5*R4 ii5+R4ii5,R4 ii5-R4ii5R./012+ h`   2  - 1 3 H"  
4?K"  345	$  !45$  
4?K"  ""  "4 5J6 *      g  doc
			_ g  tag			_ g  rest				_ g  newstyle		
	_  g  filenamef  html-document.scm
	d
	
	e			k			j			f			f		'	f	
	+	f		,	g	
	1	g		3	g	
	7	f		8	i		@	h		S	l		_	l	 			_	
	  g  nameg  gnc:html-document-set-style! C3R4567    h   L   ] L 6D       g  filenamef  html-document.scm
	x			x	* 		
   C h8      ]4 5$  	 MNC $  L  64 O 5MNC         g  elt
		6  g  filenamef  html-document.scm
	r			s	
	
	s				t			t	
		u			u	
	#	z		$	w		2	w		4	v	 		6   C       h   s   ]L LO  6       k       g  list
		  g  filenamef  html-document.scm
	p			q	 		  g  nameg  do-list C  h0      ]HO Q 4 >  "  G  JC             g  tree
		* g  retval		* g  do-list			*  g  filenamef  html-document.scm
	n
		o			o			|	 		*  g  nameg  gnc:html-document-tree-collapse C8R%)9-/:!;+'<=>?@ABCDEFGH4IJ  h(      ]	4 L5MNMN	dML 6       g  child
		( g  l		  g  filenamef  html-document.scm
 		 		 		 	.	 	!	 		 		% 	/	& 	(	( 	 		(   CKLMNOP8 !      h    - 1 3 
4 5(  "  
$  "  4 5$  
 6H4 54545 
H	4 5
44	 54
 5>  "  G  4 4	 5>  "  G  4
5$  "  4
4 5>  "  G  (  "  JKJKJK$  #$   JK"   "   4 5$   JK"   JK445 5JK4	 O >  "  G  (  "  JKJK4>   "  G  4 >  "  G  44	 5>  "  G  4 J56       g  doc
		 g  rest		 g  
stylesheet		/ g  headers?		/ g  
style-text		/ g  retval		F g  objs		O g  
work-to-do		X g  css?		_ g  	work-done			b g  title	
	k g  l	 
 g  title	= g  l	*6 g  l	P\  g  filenamef  html-document.scm
 
	
 		 		 	*	" 	&	) 		/ 		; 		E 		F 		F 		I 		O 		R 		X 		[ 		_ 		e 		k 		n 	
	q 	(	x 	(  	
  	
  	,  	
  	  	
  	  	*  	  	
  	  	.  	!  	  	.  	!  	  	.  	!  	   	"  	0  	F  	*  	$ 	. 	! 	 	! 	# 	"' 	3* 	* 	1 	.3 	!? 	B 	.D 	!E 	F 	J 	6L 	P 	P 	W 	.Y 	!] 	
 	
 	 	. 	! 	 	. 	! 	
 	
 	
 	* 	
 	 	
 U		
  g  nameg  gnc:html-document-render CQR&'  h      ] 4 56             g  doc
		 g  style		  g  filenamef  html-document.scm
 
		 		 		 	 			  g  nameg  gnc:html-document-push-style C<R'&        h       ]4 5(  C 4 56          g  doc
		  g  filenamef  html-document.scm
 
	 		
 		 		 		 	 		  g  nameg  gnc:html-document-pop-style CNR,R-S      h       ] 44 545 56         g  doc
		 g  obj		  g  filenamef  html-document.scm
 
	 		
 		 		 		 		 	 			  g  nameg  gnc:html-document-add-object! CTR,R-    h      ] 44 556         g  doc
		 g  objects		  g  filenamef  html-document.scm
 
	 		
 		 		 	 			  g  nameg  !gnc:html-document-append-objects! CUR'V.      h8   &  ]4 5H(  "  45KJ$  JC6           g  doc
		4 g  markup		4 g  
style-info		
	4 g  style-stack		
	4  g  filenamef  html-document.scm
 
	 		
 		 		 		 		! 		% 		' 		- 		4 	 		4	  g  nameg  $gnc:html-document-fetch-markup-style CWR'V1XY        h   ~   ]L  6   v       g  datum
		
 g  parms		
  g  filenamef  html-document.scm
 			 		
 	 		
	   C       hH   -  ]4 5H4 5(  "  45KJ$  JCO 6       %      g  doc
		A g  markup		A g  
style-info		
	A g  style-stack		
	A  g  filenamef  html-document.scm
 
	 		
 		 		 		 		# 		& 		* 		, 		2 		A 	 
		A	  g  nameg  "gnc:html-document-fetch-data-style CZRW[\]^_5`abcde       h8     ]M N  M N $  M N M N M N "   C       
      g  key
		1 g  value		1 g  prior			1  g  filenamef  html-document.scm
					,					,						-		,			"	,	$		&	-	)	,	+	 		1	  g  nameg  
add-attribute C45cfg     h0      ]4 5$  M N  M N C $   6C          g  attr
		-  g  filenamef  html-document.scm
				
			,		,				,			#		'	&	+	 		-  g  nameg  addextraatt Chiji  h       ]M N  M N M N C              g  tag
		  g  filenamef  html-document.scm
			3		,					,				I		,		 
		  g  nameg  add-internal-tag Ccde  h8     ]M N  M N $  M N M N M N "   C       
      g  key
		1 g  value		1 g  prior			1  g  filenamef  html-document.scm
					,					,						-		,			"	,	$		&	-	)	,	+	 		1	  g  nameg  
add-attribute C5cfg       h0      ]4 5$  M N  M N C $   6C          g  attr
		-  g  filenamef  html-document.scm
				
			,		,				,			#		'	&	+	 		-  g  nameg  addextraatt Cklmno hH  T  - 1 3 4 54545454545	HJ$  '4J5$  4J	5$  K"   "   "  KH
J$ >J$  J
J
K
J
K
$  4
O >  "  G  "   (  "  $  (4

O (  "  >  "  G  "   $  "  J
K
J
K
4

O J>  "  G  "  J
J
K
J
K
$  4
O >  "  G  "   (  "  $  (4

O (  "  >  "  G  "   $  "  J
K
J
K
"   $  "  
$  "  	$  oJ
K
$  J
K
J
K
J
K
"   $  J
K
J
K
J
K
"   	$  J
K
	J
K
J
K
"   J
K
"   J
C L      g  doc
		G g  markup		G g  end-tag?			G g  rest			G g  	childinfo		G g  tag		7G g  attr		7G g  face		7G g  size		7G g  color			7G g  retval	
	sG g  tag	 
 g  tag	-  
g  filenamef  html-document.scm
 
	
 		 						#		*		1			7		G		H		R		S	 	Y	.	[	 	_	
	b	
	r
	
	s		s		{&		~'	 '	 )	# )	  	 	, 	 	, 	 !	 !	 		 "	 "	! 		 "	! #	 $		,	%		,
	*	*	-*	-+	1 	4	,6	;	,=	C!	D!	g		r"	s"	!		"	!#	$		,	%		,	0	0	2		,	3	5		,		,	5	7	,	6	8		,	
	,	8	7	,	 9	";	%	,'	,	,.	0;	93	,5	;<	>	,@	 g		G	
	  g  nameg  gnc:html-document-markup-start CpRW[q5`rst  h       ]	MNM MNMNC       g  t
		  g  l		  g  filenamef  html-document.scm
O		P	"	K	,		K		Q		K	,	K		R	"	K	,	K	 		   g  nameg  addtag Cst4u 
     h     ]24 54545HJ$  '4J5$  4J5$  K"   "   "  KH$  JK"   J$  fO Q 4J5$   	JKJJK
JK"  $J$  44J5>  "  G  "   "   JC     w      g  doc
	  g  markup	  g  	childinfo		  g  tag		  g  closing-font-tag		  g  retval		Q  g  addtag		s  g  l	    g  filenamef  html-document.scm
?
	@		@		B		D		B		%F		&H		0F		1H	 	7H	.	9H	 	=H	
	@I	
	PG	
	QJ		QJ		YL		[M		^K	,	`K		jN		sO		{T	 S	 P	" K	, K	 Q	 K	, K	 R	" K	, K	 V	 S	 W	 W	! W	 (	 	  g  nameg  gnc:html-document-markup-end CvRwx5yz{|}~Z        h     ]HH45$  K"  G45$  K"  445$  K"  !45$  44	55K"  
K4 J5K4J54
J56       g  doc
		 g  data		 g  
style-info			 g  	data-type			  g  filenamef  html-document.scm
_
	`			c		b		d		d		e		&b		(f		*f		/g		9b		;h		=h		Bi		Lb		Mj		Pj	(	Xj		Zj		`l		bl		cn		mn		np		wq	
	p	 			  g  nameg  gnc:html-document-render-data CR4i5R4ii5R4ii5R|       h   q   ] 6      i       g  obj
		
 g  doc		
  g  filenamef  html-document.scm
		
	 		
	   C h   q   ] 6      i       g  obj
		
 g  doc		
  g  filenamef  html-document.scm
		
	 		
	   C  h    ]	H4 5$  4 5$  4 5K"  4 5$  4 5K"  4 5$  4 5K"  4	 5$  4
 5K"  l4 5$  4 5K"  R4
 5$  4 5K"  84 5$  4 5K"  4 5$   K"  4 5K"  4 $   "  5KJC            g  obj
	 g  o	  g  filenamef  html-document.scm

				
				
					&	
	+	
	5		6		@	
	E	
	O		P		Z	
	_	
	i		j		t	
	y	
 	 	 	
 	
 	 	 	
 	
 	 	 	
 	
 	 	
 	 	
 	 	 	 	 	 +	  g  nameg  gnc:make-html-object CSR4 ii5R4ii5R4 ii5R4ii5RSI h0      ]
4 5$  4 54 564 56       g  obj
		0 g  doc		0 g  htmlo		&	0  g  filenamef  html-document.scm

			
					&			 		&		0	 
		0	  g  nameg  gnc:html-object-render CIRC      -      g  filenamef  html-document.scm		
						
		
	-	 		3	 		5	!		7	 		:	
	;	$		H	#
	I	'		V	&
	)
	5	$	5	#&	5	)	4
*	8	4	8	#6	8	9	7
:	;	D	;	#F	;	I	:
J	>	T	>	#V	>	Y	=
Z	A	d	A	#f	A	i	@
j	D	t	D	#v	D	y	C
z	G		G	#	G		F
	J		J	#	J		I
	M		M	#	M		L
	P		P	#	P		O
	S		S	#	S		R
	V		V	#	V		U
	Y		Y	#	Y		X
	\		\	#	\		[
	_		_	#	_			^

	b		a
	d
	n
 
 
f 
j 
X 
 
 
# 
(2?
*_
*|	*|	*}	*|	*{
*	*~
*	*
/)
/*	/4	!/6	/9
/:	/D	!/F	/I
/J	/T	!/V	/Y
/Z	/d	!/f	/i
0
 t	0
   C6 